--=======================================================================================================
--  BALE 'SEE' SCRIPT
--
-- Author:		akuenzi (akuenzi@gmail.com)
-- Date:		1/3/2019
-- Purpose:		Allows bales and pallets to show up on the PDA map as hotspots.
--=======================================================================================================


BaleSee = {};

-- True means the mod will create hot spots for either bales or pallets.
BaleSee.baleActivate = true			-- 'True' means that the mod will create hot spots for bales.
BaleSee.palletActivate = true		-- 'True' means that the mod will create hot spots for pallets.
BaleSee.colorActivate = false		-- 'True' means that the mod will create small colored circle hotspots.
									-- 'False' means that the mod will create hotspots that are small images of the objects.

BaleSee.modDir = g_currentModDirectory

-- Hotspot rendering colors in format {Red, Green, Blue, Alpha}
BaleSee.colors =	{
			straw		= {0.6, 0.3, 0, 1},	-- Orange
			hay			= {0.4, 1, 0.4, 1},	-- Light Green
			grass		= {0.1, 0.2, 0, 1},	-- Dark Green
			silage		= {1, 1, 1, 1},		-- White
			wool		= {1, 1, 1, 1},		-- White
			pallet		= {1, 0, 1, 1},		-- Magenta
					}

-- Hotspot icons that will show on the map and in the Escape menu.
BaleSee.icons =		{
			squareStraw	= "HotspotIcons/StrawSquareBale.dds",
			squareHay	= "HotspotIcons/HaySquareBale.dds",
			squareGrass	= "HotspotIcons/GrassSquareBale.dds",
			roundStraw	= "HotspotIcons/StrawRoundBale.dds",
			roundHay	= "HotspotIcons/HayRoundBale.dds",
			roundGrass	= "HotspotIcons/GrassRoundBale.dds",
			roundSilage	= "HotspotIcons/SilageRoundBale.dds",
			woolPallet	= "HotspotIcons/WoolPallet.dds",
			otherPallet	= "HotspotIcons/Pallet.dds",
			bgImage		= "HotspotIcons/BGOverlay.dds",			-- Transparent image used as background to show hotspot icons without the usual default (black) background.
					}

-- Add hotspots for bales.
function BaleSee:delete(superFunc)

	if BaleSee.baleActivate then
		if self.mapHotspot ~= nil then
			g_currentMission.ingameMap:deleteMapHotspot(self.mapHotspot);
		end;
	end;

	superFunc(self);
	
end;

function BaleSee:setNodeId(superFunc, nodeId)

	superFunc(self, nodeId);
	
	if BaleSee.baleActivate then
		--[[Add map hot spot for each bale so they can be found.  We put this here in the code, as it's
			a location that will end up getting called by load(), loadFromAttributesAndNodes(), and readStream().]]
		local objectId = self.nodeId
		
		if BaleSee.colorActivate then
			-- Hotspots will be small colored circles.
			local width, height = getNormalizedScreenValues(3, 3);
			local color = BaleSee.colors.straw
			if self.fillType == FillUtil.FILLTYPE_DRYGRASS_WINDROW then
				color = BaleSee.colors.hay
			elseif self.fillType == FillUtil.FILLTYPE_GRASS_WINDROW then
				color = BaleSee.colors.grass
			elseif self.fillType == FillUtil.FILLTYPE_SILAGE then
				color = BaleSee.colors.silage
			end;
			
			-- Generate bale hotspot.
			self.mapHotspot = g_currentMission.ingameMap:createMapHotspot("Bale", "", nil, getNormalizedUVs({776, 776, 240, 240}), color, nil, nil, width, height, false, false, false, objectId, nil, MapHotspot.CATEGORY_DEFAULT, nil, nil, nil, nil, getNormalizedUVs({776, 776, 240, 240}), Overlay.ALIGN_VERTICAL_MIDDLE, 0.7);
		else
			-- Hotspots will be small images/icons.
			local width, height = getNormalizedScreenValues(6, 6);
			local files = BaleSee.icons
			local image = Utils.getFilename(files.squareStraw, BaleSee.modDir);
			local bgImage = Utils.getFilename(files.bgImage, BaleSee.modDir);
			
			if self.baleDiameter then
				image = Utils.getFilename(files.roundStraw, BaleSee.modDir);
				if self.fillType == FillUtil.FILLTYPE_DRYGRASS_WINDROW then
					image = Utils.getFilename(files.roundHay, BaleSee.modDir);
				elseif self.fillType == FillUtil.FILLTYPE_GRASS_WINDROW then
					image = Utils.getFilename(files.roundGrass, BaleSee.modDir);
				elseif self.fillType == FillUtil.FILLTYPE_SILAGE then
					image = Utils.getFilename(files.roundSilage, BaleSee.modDir);
				end;			
			else
				if self.fillType == FillUtil.FILLTYPE_DRYGRASS_WINDROW then
					image = Utils.getFilename(files.squareHay, BaleSee.modDir);
				elseif self.fillType == FillUtil.FILLTYPE_GRASS_WINDROW then
					image = Utils.getFilename(files.squareGrass, BaleSee.modDir);
				end;
			end;
			
			-- Generate bale hotspot.
			self.mapHotspot = g_currentMission.ingameMap:createMapHotspot("Bale", "", image, nil, nil, nil, nil, width, height, false, false, false, objectId, nil, MapHotspot.CATEGORY_DEFAULT, nil, nil, nil, bgImage, nil, Overlay.ALIGN_VERTICAL_MIDDLE, 1);
			--function IngameMap:createMapHotspot(name, fullName, imageFilename, imageUVs, baseColor, xMapPos, zMapPos, width, height, blinking, persistent, showName, objectId, renderLast, category, textSize, textOffsetY, textColor, bgImageFilename, bgImageUVs, verticalAlignment, overlayBgScale)
		end;
	end;
end;

-- Add hotspots for pallets.
function BaleSee:deletePallet(superFunc)

	if BaleSee.palletActivate then
		if self.mapHotspot ~= nil then
			g_currentMission.ingameMap:deleteMapHotspot(self.mapHotspot);
		end;
	end;

	superFunc(self);
	
end;

function BaleSee:setNodeIdPallet(superFunc, nodeId)

	superFunc(self, nodeId);

	if BaleSee.palletActivate then
		--[[Add map hot spot for each pallet so they can be found.]]
		local objectId = self.nodeId
		
		if BaleSee.colorActivate then
			-- Hotspots will be small colored circles.
			local width, height = getNormalizedScreenValues(3, 3);
			local color = BaleSee.colors.pallet;
			if self.fillType == FillUtil.FILLTYPE_WOOL then
				color = BaleSee.colors.wool;
			end;
			
			-- Generate pallet hotspot.
			self.mapHotspot = g_currentMission.ingameMap:createMapHotspot("Pallet", "", nil, getNormalizedUVs({776, 776, 240, 240}), color, nil, nil, width, height, false, false, false, objectId, nil, MapHotspot.CATEGORY_DEFAULT, nil, nil, nil, nil, getNormalizedUVs({776, 776, 240, 240}), Overlay.ALIGN_VERTICAL_MIDDLE, 0.7);
		else
			-- Hotspots will be small images/icons.
			local width, height = getNormalizedScreenValues(6, 6)
			local files = BaleSee.icons
			local image = Utils.getFilename(files.otherPallet, BaleSee.modDir);
			local bgImage = Utils.getFilename(files.bgImage, BaleSee.modDir);
			
			if self.xmlFilename then
				local storeItem = StoreItemsUtil.storeItemsByXMLFilename[string.lower(self.xmlFilename)]
				local storeImage = storeItem.imageActive
				if storeImage ~= nil then
					image = storeImage
				end;
			else
				if self.fillType == FillUtil.FILLTYPE_WOOL then
					image = Utils.getFilename(files.woolPallet, BaleSee.modDir);
				end;
			end;
			
			-- Generate pallet hotspot.
			self.mapHotspot = g_currentMission.ingameMap:createMapHotspot("Pallet", "", image, nil, nil, nil, nil, width, height, false, false, false, objectId, nil, MapHotspot.CATEGORY_DEFAULT, nil, nil, nil, bgImage, nil, Overlay.ALIGN_VERTICAL_MIDDLE, 1);
		end;
	end;
end;

-- Overwrite existing functions.
Bale.delete					= Utils.overwrittenFunction(Bale.delete, BaleSee.delete);
Bale.setNodeId				= Utils.overwrittenFunction(Bale.setNodeId, BaleSee.setNodeId);
FillablePallet.delete		= Utils.overwrittenFunction(FillablePallet.delete, BaleSee.deletePallet);
FillablePallet.setNodeId	= Utils.overwrittenFunction(FillablePallet.setNodeId, BaleSee.setNodeIdPallet);